@@ -1,5 +1,6 @@
+use crate::profile::Profile;
+use crate::report::OutputFormat;
 use crate::Scanner;
-
 use crate::{modules, Error};
 
 pub fn modules() {
@@ -8,7 +9,7 @@ pub fn modules() {
 
     println!("Subdomains modules");
     for module in subdomains_modules {
-        println!("   {}: {}", module.name(), module.description());
+        println!("    {}: {}", module.name(), module.description());
     }
 
     println!("HTTP modules");
@@ -17,7 +18,7 @@ pub fn modules() {
     }
 }
 
-pub fn scan(target: &str) -> Result<(), Error> {
+pub fn scan(target: &str, aggressive: bool, output_format: OutputFormat) -> Result<(), Error> {
     log::info!("Scanning: {}", target);
 
     let runtime = tokio::runtime::Builder::new_multi_thread()
@@ -27,9 +28,25 @@ pub fn scan(target: &str) -> Result<(), Error> {
 
     let scanner = Scanner::new();
 
-    let report = runtime.block_on(async move { scanner.scan(target).await })?;
+    let profile = if aggressive {
+        Profile::aggressive()
+    } else {
+        Profile::default()
+    };
 
-    println!("{:?}", report);
+    log::info!("Using {} profile", &profile.name);
+
+    let report = runtime.block_on(async move { scanner.scan(target, profile).await })?;
+
+    match output_format {
+        OutputFormat::Text => {
+            println!("{:?}", report);
+        }
+        OutputFormat::Json => {
+            let output = serde_json::to_string(&report)?;
+            println!("{}", output);
+        }
+    }
 
     Ok(())
 }
